Crate media_engine

Crate media_engine 

Structs

BackgroundTasksNotifies
Notifies for waking background tasks.
MediaEngine
Main type for high level interface.
MediaSourceInfo
Souce information, only exist after calling reset_input.
RealtimeStatus
Shared realtime states.
StreamExistenceFlags
indicate which stream in the input is chosen as main stream always prefer Audio Stream and fallback to Video Stream
TranscoderArgs
For constructing gpu transcoders.