pub struct StreamExistenceFlags {
pub video: bool,
pub audio: bool,
}Expand description
indicate which stream in the input is chosen as main stream always prefer Audio Stream and fallback to Video Stream
Fields
video: boolaudio: boolTrait Implementations
Sourceimpl Clone for StreamExistenceFlags
impl Clone for StreamExistenceFlags
Sourcefn clone(&self) -> StreamExistenceFlags
fn clone(&self) -> StreamExistenceFlags
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for StreamExistenceFlags
impl RefUnwindSafe for StreamExistenceFlags
impl Send for StreamExistenceFlags
impl Sync for StreamExistenceFlags
impl Unpin for StreamExistenceFlags
impl UnsafeUnpin for StreamExistenceFlags
impl UnwindSafe for StreamExistenceFlags